@@ -31,6 +31,21 @@ EntityStatusesLiterals = Literal[
 ]
 
 
+CreditScoreStatusesLiterals = Literal[
+    'completed',
+    'in_progress',
+    'pending',
+    'failed'
+]
+
+
+CreditReportBureausLiterals = Literal[
+    'experian',
+    'equifax',
+    'transunion'
+]
+
+
 class EntityIndividual(TypedDict):
     first_name: Optional[str]
     last_name: Optional[str]
@@ -126,6 +141,25 @@ class EntityGetCreditScoreResponse(TypedDict):
     score: int
     updated_at: str
 
+class EntityCreditScoresFactorsType(TypedDict):
+    code: str
+    description: str
+
+class EntityCreditScoresType(TypedDict):
+    score: int
+    source: CreditReportBureausLiterals
+    model: str
+    factors: List[EntityCreditScoresFactorsType]
+    created_at: str
+
+class EntityCreditScoresResponse(TypedDict):
+    id: str
+    status: EntityStatusesLiterals
+    credit_scores: Optional[List[EntityCreditScoresType]]
+    error: Optional[ResourceError]
+    created_at: str
+    updated_at: str
+
 class AnswerOpts(TypedDict):
     question_id: str
     answer_id: str
@@ -159,6 +193,12 @@ class EntityResource(Resource):
 
     def get_credit_score(self, _id: str) -> EntityQuestionResponse:
         return super(EntityResource, self)._get_with_sub_path('{_id}/credit_score'.format(_id=_id))
+    
+    def get_credit_scores(self, _id: str, crs_id: str) -> EntityCreditScoresResponse:
+        return super(EntityResource, self)._get_with_sub_path('{_id}/credit_scores/{crs_id}'.format(_id=_id, crs_id=crs_id))
+
+    def create_credit_scores(self, _id: str) -> EntityCreditScoresResponse:
+        return super(EntityResource, self)._create_with_sub_path('{_id}/credit_scores'.format(_id=_id), {})
 
     def update_auth_session(self, _id: str, opts: EntityUpdateAuthOpts) -> EntityUpdateAuthResponse:
         return super(EntityResource, self)._update_with_sub_path('{_id}/auth_session'.format(_id=_id), opts)
